# linefinder
A tool for finding the worldlines of Lagrangian parcels of mass, in the context of hydrodynamic simulations of galaxy formation.

Please [see the wiki for information on how to work with data products produced by the code](https://github.com/zhafen/linefinder/wiki).
